@@ -208,10 +208,7 @@ parser_finish(PyObject *self) {
 static PyObject *
 parser_reset(PyObject *self) {
     llhttp_t *llhttp = &((parser_object*)self)->llhttp;
-    uint8_t lenient_flags = llhttp->lenient_flags;
-    llhttp_init(llhttp, llhttp->type, &parser_settings);
-    llhttp->lenient_flags = lenient_flags;
-    llhttp->data = self;
+    llhttp_reset(llhttp);
     Py_RETURN_NONE;
 }
 
@@ -345,6 +342,14 @@ parser_is_busted(PyObject *self, void *closure) {
     }
 }
 
+static PyObject *
+parser_error(PyObject *self,  void *closure) {
+    llhttp_t *llhttp = &((parser_object*)self)->llhttp;
+    if (HPE_OK == llhttp_get_errno(llhttp))
+        Py_RETURN_NONE;
+    return PyUnicode_FromString(llhttp_get_error_reason(llhttp));
+}
+
 static PyGetSetDef parser_getset[] = {
     { "method", parser_method },
     { "major", parser_major },
@@ -357,6 +362,7 @@ static PyGetSetDef parser_getset[] = {
     { "is_paused", parser_is_paused },
     { "is_upgrading", parser_is_upgrading },
     { "is_busted", parser_is_busted },
+    { "error", parser_error },
     { NULL }
 };
 
